================================================
``psyclone.domain.lfric.kern_call_acc_arg_list``
================================================

.. automodule:: psyclone.domain.lfric.kern_call_acc_arg_list

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.lfric.kern_call_acc_arg_list


Classes
=======

- :py:class:`KernCallAccArgList`:
  Kernel call arguments that need to be declared by OpenACC


.. autoclass:: KernCallAccArgList
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: KernCallAccArgList
      :parts: 1
